read

Function read 

pub fn read(root: &Path) -> Result<Option<Lock>>
Read drft.lock from root. Returns Ok(None) when the file is absent or cannot be parsed (a parse failure warns and points at drft lock).