Module analyses

Module analyses 

Modules

betweenness
bridges
change_propagation
connected_components
degree
depth
graph_boundaries
graph_stats
pagerank
scc
transitive_reduction

Structs

AnalysisContext
Context passed to every analysis, providing access to the graph, filesystem root, config, and optional lockfile.

Traits

Analysis
An analysis computes structured data about the graph. Rules consume analysis results and map them to diagnostics. Metrics extract scalar values from analysis results. See docs/analyses for conceptual documentation on each analysis.