Modules
- betweenness
- bridges
- change_
propagation - connected_
components - degree
- depth
- graph_
boundaries - graph_
stats - pagerank
- scc
- transitive_
reduction
Structs
- Analysis
Context - Context passed to every analysis, providing access to the graph, filesystem root, config, and optional lockfile.
Traits
- Analysis
- An analysis computes structured data about the graph.
Rules consume analysis results and map them to diagnostics.
Metrics extract scalar values from analysis results.
See
docs/analysesfor conceptual documentation on each analysis.