SourceFile

Struct SourceFile 

pub struct SourceFile {
    pub path: String,
    pub kind: NodeKind,
    pub bytes: Option<Vec<u8>>,
}
An entry delivered by a source: its graph-relative path, kind, and — for files — its raw bytes.

Fields

path: String

Path relative to the graph root, with forward slashes.

kind: NodeKind

The kind of entry, from lstat.

bytes: Option<Vec<u8>>

Raw content. Some only for files (and None for one that could not be read). Symlinks and directories are untrackable and always carry None.